@@ -2,24 +2,24 @@ package MooseX::RemoteHelper::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.001014'; # VERSION
+our $VERSION = '0.001015'; # VERSION
 
 use MooseX::Types    -declare => [qw( Bool TrueFalse )];
 use MooseX::Types::Moose -all => { -prefix => 'Moose' };
 
 subtype TrueFalse, as MooseStr,
 	where {
-		$_ =~ m/^(true|t|f|false|enabled|disabled)$/ixms;
+		$_ =~ m/^(true|t|f|false|enable[d]?|disable[d]?)|yes|y|no|n$/ixms;
 	};
 
 subtype Bool, as MooseBool;
 coerce  Bool, from TrueFalse,
 	via {
 		my $val = lc $_;
-		if ( $val =~ m/^t/xms || $val eq 'enabled' ) {
+		if ( $val =~ m/^(t|enable|y)/xms ) {
 			return 1;
 		}
-		elsif ( $val eq 'disabled' ) {
+		elsif ( $val =~  /^(f|disable|n)/xms ) {
 			return 0;
 		}
 		return 0;
@@ -38,7 +38,7 @@ MooseX::RemoteHelper::Types - Types to help with things commonly needed by remot
 
 =head1 VERSION
 
-version 0.001014
+version 0.001015
 
 =head1 SUBROUTINES
 
@@ -46,7 +46,7 @@ version 0.001014
 
 coerces from string where values could match (case insensitive):
 
-	true, t, false, f, enabled, disabled
+	true, t, false, f, enable[d], disable[d], yes, y, no, n
 
 =head1 BUGS
 
